src/eric7/WebBrowser/Bookmarks/BookmarksImporters/OperaImporter.py

branch
eric7
changeset 9504
1193fc2bf192
parent 9489
c03b8323d11a
child 9624
b47dfa7a137d
--- a/src/eric7/WebBrowser/Bookmarks/BookmarksImporters/OperaImporter.py	Wed Nov 09 15:18:07 2022 +0100
+++ b/src/eric7/WebBrowser/Bookmarks/BookmarksImporters/OperaImporter.py	Fri Nov 11 15:30:47 2022 +0100
@@ -28,7 +28,7 @@
         (string)
     @exception ValueError raised to indicate an invalid browser ID
     """
-    if sourceId != "opera":
+    if sourceId != "opera_legacy":
         raise ValueError("Unsupported browser ID given ({0}).".format(sourceId))
 
     if Globals.isWindowsPlatform():
@@ -38,12 +38,12 @@
     else:
         standardDir = os.path.expanduser("~/.opera")
     return (
-        EricPixmapCache.getPixmap("opera"),
-        "Opera",
+        EricPixmapCache.getPixmap("opera_legacy"),
+        "Opera (Legacy)",
         "bookmarks.adr",
         QCoreApplication.translate(
             "OperaImporter",
             """Opera stores its bookmarks in the <b>bookmarks.adr</b> """
             """text file. This file is usually located in""",
         ),
         QCoreApplication.translate(
@@ -134,7 +134,7 @@
             importRootNode.title = self.tr("Opera Import")
         else:
             importRootNode.title = self.tr("Imported {0}").format(
-                QDate.currentDate().toString(Qt.DateFormat.SystemLocaleShortDate)
+                QDate.currentDate().toString(Qt.DateFormat.ISODate)
             )
         return importRootNode
 
@@ -38,12 +38,12 @@
         QCoreApplication.translate(
             "OperaImporter",
-            """Opera stores its bookmarks in the <b>bookmarks.adr</b> """
+            """Opera (Legacy) stores its bookmarks in the <b>bookmarks.adr</b> """
             """text file. This file is usually located in""",
         ),

eric ide

mercurial